@@ -442,7 +442,7 @@ class Chat:
         )
         for i in range(len(result_list)):
             src = result_list[i]
-            batch_result[i].narrow(1, 0, achatbot.size(0)).copy_(achatbot.permute(1, 0))
+            batch_result[i].narrow(1, 0, src.size(0)).copy_(src.permute(1, 0))
             del src
         del_all(result_list)
         mel_specs = decoder(batch_result)
