@@ -10,9 +10,7 @@ class GrpcStreamClientConnector(IConnector):
     def __init__(self, target="localhost:50052", token="chat-bot-connenctor") -> None:
         self.in_q = queue.Queue()
         self.out_q = queue.Queue()
-        self.cli = StreamClient(
-            in_q=self.in_q, out_q=self.out_q,
-            target=target, token=token)
+        self.cli = StreamClient(in_q=self.in_q, out_q=self.out_q, target=target, token=token)
         self.cli.start()
 
     def send(self, data, at: str = "fe"):
@@ -34,8 +32,7 @@ class GrpcStreamServeConnector(IConnector):
     def __init__(self, port="50052", token="chat-bot-connenctor") -> None:
         self.in_q = queue.Queue()
         self.out_q = queue.Queue()
-        self.serve = StreamServe(in_q=self.in_q, out_q=self.out_q,
-                                 port=port, token=token)
+        self.serve = StreamServe(in_q=self.in_q, out_q=self.out_q, port=port, token=token)
         self.serve.start()
 
     def send(self, data, at: str = "be"):
