@@ -1,16 +1,33 @@
 import logging
 import inspect
+from typing import Dict
+
+from achatbot.common.utils.obj import obj_count, obj_id
 
 
 class EventHandlerManager:
+    def __init__(self, name: str = None):
+        self._id: int = obj_id()
+        self._name = name or f"{self.__class__.__name__}#{obj_count(self)}"
+        self._event_handlers: Dict[str, list] = {}
 
-    def __init__(self):
-        self._event_handlers: dict = {}
+    @property
+    def id(self) -> int:
+        return self._id
+
+    @property
+    def name(self) -> str:
+        return self._name
+
+    @property
+    def event_names(self):
+        return self._event_handlers.keys()
 
     def event_handler(self, event_name: str):
         def decorator(handler):
             self.add_event_handler(event_name, handler)
             return handler
+
         return decorator
 
     def _register_event_handler(self, event_name: str):
@@ -23,6 +40,11 @@ class EventHandlerManager:
             raise Exception(f"Event handler {event_name} not registered")
         self._event_handlers[event_name].append(handler)
 
+    def add_event_handlers(self, event_name: str, handlers: list):
+        if event_name not in self._event_handlers:
+            raise Exception(f"Event handler {event_name} not registered")
+        self._event_handlers[event_name].extend(handlers)
+
     async def _call_event_handler(self, event_name: str, *args, **kwargs):
         try:
             for handler in self._event_handlers[event_name]:
