@@ -12,6 +12,7 @@ class OpenWeatherMap(WeatherBaseApi):
     - https://openweathermap.org/api/one-call-3#data
     - https://openweathermap.org/api/one-call-3#multi
     """
+
     BASE_URL = "https://api.openweathermap.org/data/2.5/weather"
     TAG = "openweathermap_api"
 
@@ -19,9 +20,7 @@ class OpenWeatherMap(WeatherBaseApi):
         super().__init__()
         self.args = OpenWeatherMapArgs(**args)
 
-    def _get_weather(self, session,
-                     longitude: float,
-                     latitude: float) -> str:
+    def _get_weather(self, session, longitude: float, latitude: float) -> str:
         api_key = os.getenv("OPENWEATHERMAP_API_KEY", "")
         url = f"{OpenWeatherMap.BASE_URL}?appid={api_key}&lat={latitude}&lon={longitude}&lang={self.args.lang}&units={self.args.units}"
         try:
