@@ -10,10 +10,11 @@ class DailyWebRTCVADAnalyzer(BaseVADAnalyzer):
     def __init__(self, **args):
         super().__init__(**args)
         from daily import Daily
+
         self._webrtc_vad = Daily.create_native_vad(
             reset_period_ms=DAILY_WEBRTC_VAD_RESET_PERIOD_MS,
             sample_rate=self._args.sample_rate,
-            channels=self._args.num_channels
+            channels=self._args.num_channels,
         )
         logging.debug("Loaded native WebRTC VAD")
 
