@@ -1,4 +1,3 @@
-
 from abc import abstractmethod
 from typing import AsyncGenerator
 
@@ -8,8 +7,8 @@ from achatbot.types.frames.data_frames import VisionImageRawFrame, Frame
 from achatbot.processors.ai_processor import AIProcessor
 
 
-class VisionProcessor(AIProcessor):
-    """VisionProcessor is a base class for vision processors."""
+class VisionProcessorBase(AIProcessor):
+    """VisionProcessorBase is a base class for vision processors."""
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
